AddendumLines

Struct AddendumLines 

pub(super) struct AddendumLines {
    lines: Vec<AddendumLine>,
}
All addenda associated with a relation, in canonical text-format order.

Fields

lines: Vec<AddendumLine>

Implementations

Source

impl AddendumLines

pub(super) fn from_advanced_extension<S: Scope>( ctx: &S, advanced_extension: Option<&AdvancedExtension>, ) -> Self

pub(super) fn extension_table<S: Scope>( ctx: &S, extension_table: Result<(String, ExtensionArgs), ExtensionError>, advanced_extension: Option<&AdvancedExtension>, ) -> Self

pub(super) fn none() -> Self

fn extend_from_advanced_extension<S: Scope>( &mut self, ctx: &S, advanced_extension: &AdvancedExtension, )

Add AddendumLines to this AddendumLines instance for each enhancement and optimization present in the AdvancedExtension.